/*
//====================================================================
// FlagHitCylinder.
// Last Edited On 05 April 2005
// Copyright (C) 2005 L7 (L7@noobed.com)
// This program is free software; you can redistribute it and/or
// modify it under the terms of the Open Unreal Mod License.
//====================================================================
*/
class FlagHitCylinder extends Actor;

var MutFlagProtection MutFP;

var int TeamNum;
var bool bDropped;

var float NextPainTime;
var sound FlagHitSound;

/*
================
BeginPlay.
================
*/
function BeginPlay()
{
    Super.BeginPlay();

    if ( SissyFlag(Owner) != None ) {

        TeamNum = SissyFlag(Owner).TeamNum;
        bDropped = SissyFlag(Owner).bDropped;

        if ( !bDropped ) {
            SetCollisionSize( MutFP.default.BasedHitRadius, MutFP.default.BasedHitHeight );
        } else {
            SetCollisionSize( MutFP.default.DroppedHitRadius, MutFP.default.DroppedHitHeight );
        }
    } else {
        Destroy();
    }
}

/*
================
TakeDamage.
================
*/
function TakeDamage( int Damage, Pawn Instigator, Vector HitLocation, Vector Momentum, class<DamageType> DamageType )
{
    local int InstigatorTeam;
    local int OriginalDamage;
    local FlagPenalty Penalty;

    if ( ( Instigator != None ) && ( Damage > 0 ) ) {

        InstigatorTeam = Instigator.GetTeamNum();
        OriginalDamage = Damage;

        // broadcast hit sound
        PlaySound( sound'WeaponSounds.ShieldGun.ShieldReflection', SLOT_Interact, 2.5 * TransientSoundVolume );

        // broadcast hit effect
        if ( Level.TimeSeconds >= NextPainTime ) {

            switch ( TeamNum )
            {
                case 0:
                    Spawn( class'NewTransEffect' );
                    break;
                case 1:
                    Spawn( class'NewTransEffectBlue' );
                    break;
                default:
                    break;
            }

            NextPainTime = Level.TimeSeconds + 0.75;
        }

        // client hit sound
        if ( ( Instigator.Controller != None ) &&
             ( PlayerController(Instigator.Controller) != None ) ) {
            PlayerController(Instigator.Controller).ClientPlaySound( default.FlagHitSound );
        }

        // determine penalty damage

        if ( ( !MutFP.default.bPenalizeCarriers ) &&
             ( Instigator.PlayerReplicationInfo != None ) &&
             ( Instigator.PlayerReplicationInfo.HasFlag != None ) ) {
            return;
        }

        if ( ( MutFP.default.bSameFlagHitPenalty && ( TeamNum == InstigatorTeam ) ) ||
             ( MutFP.default.bOtherFlagHitPenalty && ( TeamNum != InstigatorTeam ) ) ) {
            if ( !bDropped ) {
                Damage = MutFP.default.BasedHitDamage;
            } else {
                Damage = MutFP.default.DroppedHitDamage;
            }
        } else {
            return;
        }

        if ( Damage == 17 ) {
            Damage = OriginalDamage;
        }

        if ( Damage <= 0 ) return;

        Penalty = Spawn( class'FlagPenalty', Instigator );

        if ( Penalty != None ) {
            Penalty.PenalizePawn( Damage, TeamNum );
        }
    }
}

/*
================
Tick.
================
*/
function Tick( float DeltaTime )
{
    if ( ( Owner != None ) &&
         ( SissyFlag(Owner).Cylinder != None ) &&
         ( SissyFlag(Owner).Cylinder == self ) ) {

        if ( bDropped ) {
            SetLocation( Owner.Location );
            SetRotation( Owner.Rotation );
        }
    } else {
        Destroy();
    }
}

defaultproperties
{
    DrawType=DT_None
    Physics=PHYS_None
    bCanBeDamaged=true
    CollisionRadius=0.000000
    CollisionHeight=0.000000
    bCollideActors=true
    bCollideWorld=false
    bBlockActors=false
    bProjTarget=true
    bUseCylinderCollision=true
    FlagHitSound=sound'WeaponSounds.TAGRifle.TAGTargetAquired'
}
