/*
//====================================================================
// FlagProtectionRules.
// Last Edited On 05 April 2005
// Copyright (C) 2005 L7 (L7@noobed.com)
// This program is free software; you can redistribute it and/or
// modify it under the terms of the Open Unreal Mod License.
//====================================================================
*/
class FlagProtectionRules extends GameRules;

var MutFlagProtection MutFP;

var Material ProtectionMat;
var Material RedProtectionMat;
var Material BlueProtectionMat;
var float ProtectionMatTime;
var sound CarrierHitSound;

/*
================
NetDamage.
================
*/
function int NetDamage( int OriginalDamage, int Damage, Pawn Injured, Pawn InstigatedBy, Vector HitLocation, out Vector Momentum, class<DamageType> DamageType )
{
    local UnrealPawn P, OldHolder;
    local SissyFlag  F;

    P = UnrealPawn(Injured);

    if ( ( InstigatedBy != None ) &&
         ( P != None ) &&
         ( InstigatedBy != P ) &&
         ( P.PlayerReplicationInfo != None ) &&
         ( P.PlayerReplicationInfo.HasFlag != None ) ) {

        F = SissyFlag(P.PlayerReplicationInfo.HasFlag);

        if ( F != None ) {

            OldHolder = F.OldHolder;

            if ( ( OldHolder == None ) || ( P != OldHolder ) ) {

                if ( !F.bDropped ) {

                    if ( ( F.PickupTime + MutFP.default.BasedProtectionTime ) >= Level.TimeSeconds ) {

                        if ( ( MutFP.default.BasedProtectionRadius <= 0.f ) ||
                             ( VSize( P.Location - F.FlagOrigin ) <= MutFP.default.BasedProtectionRadius ) ) {
                            SpawnProtectionEffects( P );
                            PlayCarrierHitSound( InstigatedBy );
                            Momentum = Vect(0,0,0);
                            return 0;
                        }
                    }
                } else {

                    if ( ( F.PickupTime + MutFP.default.DroppedProtectionTime ) >= Level.TimeSeconds ) {

                        if ( ( MutFP.default.DroppedProtectionRadius <= 0.f ) ||
                             ( VSize( P.Location - F.FlagOrigin ) <= MutFP.default.DroppedProtectionRadius ) ) {
                            SpawnProtectionEffects( P );
                            PlayCarrierHitSound( InstigatedBy );
                            Momentum = Vect(0,0,0);
                            return 0;
                        }
                    }
                }
            }
        }
    }

    if ( NextGameRules != None ) {
        return NextGameRules.NetDamage( OriginalDamage, Damage, Injured, InstigatedBy, HitLocation, Momentum, DamageType );
    }

    return Damage;
}

/*
=======================
SpawnProtectionEffects.
=======================
*/
function SpawnProtectionEffects( Pawn P )
{
    local int Team;

    if ( P != None ) {

        Team = P.GetTeamNum();

        switch ( Team )
        {
            case 0:
                P.SetOverlayMaterial( RedProtectionMat, ProtectionMatTime, true );
                break;
            case 1:
                P.SetOverlayMaterial( BlueProtectionMat, ProtectionMatTime, true );
                break;
            default:
                P.SetOverlayMaterial( ProtectionMat, ProtectionMatTime, true );
                break;
        }

        P.PlaySound( sound'WeaponSounds.ArmorHit', SLOT_Pain, 2 * TransientSoundVolume,, 400 );
    }
}

/*
====================
PlayCarrierHitSound.
====================
*/
function PlayCarrierHitSound( Pawn P )
{
    if ( ( P != None ) &&
         ( P.Controller != None ) &&
         ( PlayerController(P.Controller) != None ) ) {
        PlayerController(P.Controller).ClientPlaySound( default.CarrierHitSound );
    }
}

defaultproperties
{
    ProtectionMat=Material'XGameShaders.PlayerShaders.WeaponUDamageShader'
    RedProtectionMat=Material'XGameShaders.PlayerShaders.PlayerTransPanRed'
    BlueProtectionMat=Material'XGameShaders.PlayerShaders.PlayerTransPan'
    ProtectionMatTime=0.800000
    CarrierHitSound=sound'GeneralAmbience.beep5'
}
