/*
//====================================================================
// MutFlagProtection.
// Last Edited On 05 April 2005
// Copyright (C) 2005 L7 (L7@noobed.com)
// This program is free software; you can redistribute it and/or
// modify it under the terms of the Open Unreal Mod License.
//====================================================================
*/
class MutFlagProtection extends Mutator
    config( FlagProtection );

var config float BasedProtectionTime;
var config float BasedProtectionRadius;
var config float DroppedProtectionTime;
var config float DroppedProtectionRadius;

var config float BasedHitRadius;
var config float BasedHitHeight;
var config int   BasedHitDamage;

var config float DroppedHitRadius;
var config float DroppedHitHeight;
var config int   DroppedHitDamage;

var config bool bSameFlagHitPenalty;
var config bool bOtherFlagHitPenalty;
var config bool bPenalizeCarriers;
var config bool bBroadcastPenaltyMessages;

var localized string GUIDisplayText[14];
var localized string GUIDescText[14];

/*
========================
UpdatePrecacheMaterials.
========================
*/
simulated function UpdatePrecacheMaterials()
{
    Level.AddPrecacheMaterial( Material'XGameShaders.PlayerShaders.PlayerTransPan' );
    Level.AddPrecacheMaterial( Material'XGameShaders.PlayerShaders.PlayerTransPanRed' );
    Level.AddPrecacheMaterial( Material'XGameShaders.PlayerShaders.WeaponUDamageShader' );

    Super.UpdatePrecacheMaterials();
}

/*
=================
CheckReplacement.
=================
*/
function bool CheckReplacement( Actor Other, out byte bSuperRelevant )
{
    bSuperRelevant = 0;

    if ( FlagPenalty(Other) != None ) {
        FlagPenalty(Other).bBroadcastPenaltyMessages = bBroadcastPenaltyMessages;
        return true;
    }

    if ( FlagHitCylinder(Other) != None ) {
        FlagHitCylinder(Other).MutFP = self;
        return true;
    }

    if ( xRealCTFBase(Other) != None ) {
        if ( Other.IsA( 'xRedFlagBase' ) ) {
            xRedFlagBase(Other).FlagType = class'RedSissyFlag';
            return true;
        }
        else if ( Other.IsA( 'xBlueFlagBase' ) ) {
            xBlueFlagBase(Other).FlagType = class'BlueSissyFlag';
            return true;
        }
    }

    if ( SissyFlag(Other) != None ) {
        SissyFlag(Other).MutFP = self;
        return true;
    }

    return true;
}

/*
================
PostBeginPlay.
================
*/
function PostBeginPlay()
{
    local FlagProtectionRules FPR;

    Super.PostBeginPlay();

    FPR = Spawn( class'FlagProtectionRules' );
    FPR.MutFP = self;

    if ( Level.Game.GameRulesModifiers == None ) {
        Level.Game.GameRulesModifiers = FPR;
    } else {
        Level.Game.GameRulesModifiers.AddGameRules( FPR );
    }
}

/*
================
FillPlayInfo.
================
*/
static function FillPlayInfo( PlayInfo PlayInfo )
{
    Super.FillPlayInfo( PlayInfo );

    PlayInfo.AddSetting(default.RulesGroup,"BasedProtectionTime",GetDisplayText("BasedProtectionTime"),0,40,"Text","8;0.00:5.00",,,);
    PlayInfo.AddSetting(default.RulesGroup,"BasedProtectionRadius",GetDisplayText("BasedProtectionRadius"),0,41,"Text","10;0:500",,,);
    PlayInfo.AddSetting(default.RulesGroup,"DroppedProtectionTime",GetDisplayText("DroppedProtectionTime"),0,42,"Text","8;0.00:5.00",,,);
    PlayInfo.AddSetting(default.RulesGroup,"DroppedProtectionRadius",GetDisplayText("DroppedProtectionRadius"),0,43,"Text","10;0:500",,,);
    PlayInfo.AddSetting(default.RulesGroup,"BasedHitRadius",GetDisplayText("BasedHitRadius"),0,44,"Text","9;0.00:60.00",,,);
    PlayInfo.AddSetting(default.RulesGroup,"BasedHitHeight",GetDisplayText("BasedHitHeight"),0,45,"Text","9;0.00:90.00",,,);
    PlayInfo.AddSetting(default.RulesGroup,"BasedHitDamage",GetDisplayText("BasedHitDamage"),0,46,"Text","4;0:1000",,,);
    PlayInfo.AddSetting(default.RulesGroup,"DroppedHitRadius",GetDisplayText("DroppedHitRadius"),0,47,"Text","9;0.00:60.00",,,);
    PlayInfo.AddSetting(default.RulesGroup,"DroppedHitHeight",GetDisplayText("DroppedHitHeight"),0,48,"Text","9;0.00:90.00",,,);
    PlayInfo.AddSetting(default.RulesGroup,"DroppedHitDamage",GetDisplayText("DroppedHitDamage"),0,49,"Text","4;0:1000",,,);
    PlayInfo.AddSetting(default.RulesGroup,"bSameFlagHitPenalty",GetDisplayText("bSameFlagHitPenalty"),0,50,"Check",,,,);
    PlayInfo.AddSetting(default.RulesGroup,"bOtherFlagHitPenalty",GetDisplayText("bOtherFlagHitPenalty"),0,51,"Check",,,,);
    PlayInfo.AddSetting(default.RulesGroup,"bPenalizeCarriers",GetDisplayText("bPenalizeCarriers"),0,52,"Check",,,,True);
    PlayInfo.AddSetting(default.RulesGroup,"bBroadcastPenaltyMessages",GetDisplayText("bBroadcastPenaltyMessages"),0,53,"Check",,,,True);
}

/*
================
GetDisplayText.
================
*/
static function string GetDisplayText( string PropName )
{
    switch ( PropName )
    {
        case "BasedProtectionTime":
            return default.GUIDisplayText[0];
        case "BasedProtectionRadius":
            return default.GUIDisplayText[1];
        case "DroppedProtectionTime":
            return default.GUIDisplayText[2];
        case "DroppedProtectionRadius":
            return default.GUIDisplayText[3];
        case "BasedHitRadius":
            return default.GUIDisplayText[4];
        case "BasedHitHeight":
            return default.GUIDisplayText[5];
        case "BasedHitDamage":
            return default.GUIDisplayText[6];
        case "DroppedHitRadius":
            return default.GUIDisplayText[7];
        case "DroppedHitHeight":
            return default.GUIDisplayText[8];
        case "DroppedHitDamage":
            return default.GUIDisplayText[9];
        case "bSameFlagHitPenalty":
            return default.GUIDisplayText[10];
        case "bOtherFlagHitPenalty":
            return default.GUIDisplayText[11];
        case "bPenalizeCarriers":
            return default.GUIDisplayText[12];
        case "bBroadcastPenaltyMessages":
            return default.GUIDisplayText[13];
    }
}

/*
===================
GetDescriptionText.
===================
*/
static event string GetDescriptionText( string PropName )
{
    switch ( PropName )
    {
        case "BasedProtectionTime":
            return default.GUIDescText[0];
        case "BasedProtectionRadius":
            return default.GUIDescText[1];
        case "DroppedProtectionTime":
            return default.GUIDescText[2];
        case "DroppedProtectionRadius":
            return default.GUIDescText[3];
        case "BasedHitRadius":
            return default.GUIDescText[4];
        case "BasedHitHeight":
            return default.GUIDescText[5];
        case "BasedHitDamage":
            return default.GUIDescText[6];
        case "DroppedHitRadius":
            return default.GUIDescText[7];
        case "DroppedHitHeight":
            return default.GUIDescText[8];
        case "DroppedHitDamage":
            return default.GUIDescText[9];
        case "bSameFlagHitPenalty":
            return default.GUIDescText[10];
        case "bOtherFlagHitPenalty":
            return default.GUIDescText[11];
        case "bPenalizeCarriers":
            return default.GUIDescText[12];
        case "bBroadcastPenaltyMessages":
            return default.GUIDescText[13];
    }
}

defaultproperties
{
    bAddToServerPackages=true
    IconMaterialName="MutatorArt.nosym"
    ConfigMenuClassName=""
    GroupName="Flag"
    FriendlyName="Flag Protection"
    Description="Adds options to prevent flag camping and flag spamming in CTF gametypes."

    BasedProtectionTime=2.000000
    BasedProtectionRadius=250.000000
    DroppedProtectionTime=2.000000
    DroppedProtectionRadius=250.000000
    BasedHitRadius=48.000000
    BasedHitHeight=60.000000
    BasedHitDamage=17
    DroppedHitRadius=32.000000
    DroppedHitHeight=40.000000
    DroppedHitDamage=17
    bSameFlagHitPenalty=true
    bOtherFlagHitPenalty=true
    bPenalizeCarriers=false
    bBroadcastPenaltyMessages=true

    GUIDisplayText[0]="Based Protection Time"
    GUIDisplayText[1]="Based Protection Radius"
    GUIDisplayText[2]="Dropped Protection Time"
    GUIDisplayText[3]="Dropped Protection Radius"
    GUIDisplayText[4]="Based Hit Radius"
    GUIDisplayText[5]="Based Hit Height"
    GUIDisplayText[6]="Based Hit Damage"
    GUIDisplayText[7]="Dropped Hit Radius"
    GUIDisplayText[8]="Dropped Hit Height"
    GUIDisplayText[9]="Dropped Hit Damage"
    GUIDisplayText[10]="Same Flag Hit Penalty"
    GUIDisplayText[11]="Other Flag Hit Penalty"
    GUIDisplayText[12]="Penalize Carriers"
    GUIDisplayText[13]="Broadcast Penalty Messages"
    GUIDescText[0]="Sets the protection time of a based flag."
    GUIDescText[1]="Sets the protection radius around a flag base.  Use 0 to disable the radius check."
    GUIDescText[2]="Sets the protection time of a dropped flag."
    GUIDescText[3]="Sets the protection radius around a dropped flag.  Use 0 to disable the radius check."
    GUIDescText[4]="Sets the radius of a based flag's hit cylinder."
    GUIDescText[5]="Sets the height of a based flag's hit cylinder."
    GUIDescText[6]="Sets the penalty damage for hitting a based flag.  Use 17 to penalize the actual hit damage."
    GUIDescText[7]="Sets the radius of a dropped flag's hit cylinder."
    GUIDescText[8]="Sets the height of a dropped flag's hit cylinder."
    GUIDescText[9]="Sets the penalty damage for hitting a dropped flag.  Use 17 to penalize the actual hit damage."
    GUIDescText[10]="Damages players for shooting their team's flag."
    GUIDescText[11]="Damages players for shooting the other team's flag."
    GUIDescText[12]="Allows flag penalty damage to hurt flag carriers."
    GUIDescText[13]="Broadcasts flag penalty death messages to all players."
}
